VERSION 8000
* Allg_BspDA23Import.CSX  Import Breiten aus REB DA 23  03.03.10
* -----------------------------------------------------------------------------
* @filedoc
* @file Allg_BspDA23Import.CSX
* @brief Fahrspurbreiten im Format REB DA 23 importieren
* 
* Dieses Beispielskript bernimmt Fahrspurbreiten im Format REB DA 23 in ein CARD/1 Breiteband. 
* Genutzt werden hierfr die Methoden der Klasse /STRING/.
* Es wird jeweils ein Breiteband fr die linke und rechte Seite des Querschnittes erstellt
* (Dateien: BRT_links.CRD und BRT_rechts.CRD). 
* Den Achsbezug fr die Breitebnder stellen Sie durch nachtrgliches ndern des Dateinamens her.
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author CK
* @endfiledoc
* -----------------------------------------------------------------------------
* @history
*
* --- Vereinbarungen ----------------------------------------------------------
 
BILDSCHIRM GRAFIK

* --- Deklarationen -----------------------------------------------------------

SYMBOLE /STRING/ String; KaNr; BrZeile
SYMBOLE * !Name; ZZ; Stat; B1; DH2; B3 
 
* --- Ausfhrungen ------------------------------------------------------------

* neue Objekte der Hilfsklasse /STRING/ erzeugen
String = NEWOBJECT /STRING/
KaNr = NEWOBJECT /STRING/
BrZeile = NEWOBJECT /STRING/

* REB-Datei auswhlen
!Name= !DAT_WAHL("*.D23"; 5)
WENN T_GLEICH(!Name; " ") DANN                    | Prfung, ob Datei ausgewhlt wurde
  STOP MELDE "Keine Datei gewhlt --> Bearbeitung wird abgebrochen!"
WEITER

* REB-Datei ffnen
DAT_AUF 1; NAME = !Name 
    
* neue Breitebnder links und rechts anlegen und ffnen
DAT_NEU 2; NAME = "BRT_links.CRD"; BEZ = "Breiteliste aus REB DA 23"
DAT_SCHREIBEN 2; "VERSION 8000"
DAT_NEU 3; NAME = "BRT_rechts.CRD"; BEZ = "Breiteliste aus REB DA 23"
DAT_SCHREIBEN 3; "VERSION 8000"

*Schleife ber alle Datenzeilen der REB-Datei
SOLANGE ZZ = String.ReadFile(1) == 1             | liest alle Datenzeilen aus REB-Datei (Nr. 1)

  String.SetDelimiter(" ")                       | setzt Leerzeichen als Trennzeichen 

  * einzelne Werte aus der Datenzeile zuordnen
  KaNr = String.GetNextSubString()               | Kartenart und Kennziffer als String
  Stat = String.GetNextNumber()                  | Station 
  B1 = String.GetNextNumber()                    | Breite 1.Spur     
  DH2 = String.GetNextNumber()                   | Hhendifferenz zw. 1. und 2. Spuranteil (Hochbord)
  B3 = String.GetNextNumber()                    | Breite 2. Spur

  WENN KaNr == $NULL DANN STOP MELDE "Keine Daten --> Bearbeitung wird abgebrochen!"

  WENN KaNr.IsEqual("023+1") == 0 DANN           | Prfung: Kennungstext nicht fr rechte Seite? 
    WENN KaNr.IsEqual("023-1") == 0 DANN NCHSTE SOLANGE  | wenn Kennungstext auch nicht fr linke Seite ==>Zeile ignorieren
    * Daten in Breiteband linke Seite schreiben    
    BrZeile.SetDelimiter(";")                    | setzt Semikolon als Trennzeichen
    BrZeile.AddText("B"; 0)                      | fgt Text "B" in Textobjekt "BrZeile" ein
    BrZeile.AddNumber(Stat; 3; 3)                | fgt Station in Textobjekt "BrZeile" ein
    BrZeile.AddNumber(B1; 3; 3)                  | fgt Breite in Textobjekt "BrZeile" ein
    BrZeile.WriteFile(2)                         | schreibt Textobjekt "BrZeile" in Datei Nr. 2
    BrZeile.Clear()                              | lscht den Text des Textobjektes "BrZeile" 
  SONST
    * Daten in Breiteband rechte Seite schreiben
    BrZeile.SetDelimiter(";")                    | setzt Semikolon als Trennzeichen 
    BrZeile.AddText("B"; 0)                      | fgt Text "B" in Textobjekt "BrZeile" ein
    BrZeile.AddNumber(Stat; 3; 3)                | fgt Station in Textobjekt "BrZeile" ein
    BrZeile.AddNumber(B1; 3; 3)                  | fgt Breite in Textobjekt "BrZeile" ein
    BrZeile.WriteFile(3)                         | schreibt Textobjekt "BrZeile" in Datei Nr. 3
    BrZeile.Clear()                              | lscht den Text des Textobjektes "BrZeile"
  WEITER     

ENDE SOLANGE                               

* Dateien schlieen
DAT_ZU 1
DAT_ZU 2
DAT_ZU 3